==> jc-1.4.0.tar.gz: java/util/TreeMap__24Node.h <==
// final class java.util.TreeMap$Node

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class 1262f916aabf61fb java_util_TreeMap__24Node

// header file dependencies
// @dep_header java_util_AbstractMap__24BasicMapEntry

#include "java/util/AbstractMap__24BasicMapEntry.h"

#ifndef _JC_java_util_TreeMap__24Node_H_
#define _JC_java_util_TreeMap__24Node_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_TreeMap__24Node$object;

// Typedefs
typedef struct _jc_java_util_TreeMap__24Node$sub_refs	_jc_java_util_TreeMap__24Node$sub_refs;
typedef struct _jc_java_util_TreeMap__24Node$sub_nonrefs	_jc_java_util_TreeMap__24Node$sub_nonrefs;
typedef struct _jc_java_util_TreeMap__24Node$refs	_jc_java_util_TreeMap__24Node$refs;
typedef struct _jc_java_util_TreeMap__24Node$nonrefs	_jc_java_util_TreeMap__24Node$nonrefs;
typedef struct _jc_java_util_TreeMap__24Node$object	_jc_java_util_TreeMap__24Node$object;

typedef const struct _jc_java_util_TreeMap__24Node$vmethods	_jc_java_util_TreeMap__24Node$vmethods;
typedef const struct _jc_java_util_TreeMap__24Node$vtable	_jc_java_util_TreeMap__24Node$vtable;
typedef const struct _jc_java_util_TreeMap__24Node$vtype	_jc_java_util_TreeMap__24Node$vtype;

// Constructors
extern void _jc_java_util_TreeMap__24Node$method$_init$a804effe5455d5e8(_jc_env *, struct _jc_java_util_TreeMap__24Node$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern void _jc_java_util_TreeMap__24Node$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_TreeMap__24Node$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_TreeMap__24Node$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_TreeMap__24Node$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_TreeMap__24Node$object *);
};

// Vtable
struct _jc_java_util_TreeMap__24Node$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_TreeMap__24Node$vmethods	java_util_TreeMap__24Node;
};

// Vtype
struct _jc_java_util_TreeMap__24Node$vtype {
	_jc_type			type;
	_jc_java_util_TreeMap__24Node$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_TreeMap__24Node$sub_refs {
	struct _jc_java_util_TreeMap__24Node$object	*left;
	struct _jc_java_util_TreeMap__24Node$object	*right;
	struct _jc_java_util_TreeMap__24Node$object	*parent;
};

// Reference instance fields (object)
struct _jc_java_util_TreeMap__24Node$refs {
    _jc_java_util_TreeMap__24Node$sub_refs	java_util_TreeMap__24Node;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_TreeMap__24Node$sub_nonrefs {
	jint	color;
};

// Non-reference instance fields (object)
struct _jc_java_util_TreeMap__24Node$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_TreeMap__24Node$sub_nonrefs	java_util_TreeMap__24Node;
};

// Object instance structure
struct _jc_java_util_TreeMap__24Node$object {
	_jc_java_util_TreeMap__24Node$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_TreeMap__24Node$vtype	*vtype;
	_jc_java_util_TreeMap__24Node$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_TreeMap__24Node$vtype _jc_java_util_TreeMap__24Node$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_TreeMap__24Node, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_TreeMap__24Node$class_object;

#endif	/* _JC_java_util_TreeMap__24Node_H_ */

==> jc-1.4.6.tar.gz: java/util/TreeMap__24Node.h <==
// final class java.util.TreeMap$Node

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class 1262f916aabf61fb java_util_TreeMap__24Node

// header file dependencies
// @dep_header java_util_AbstractMap__24BasicMapEntry

#include "java/util/AbstractMap__24BasicMapEntry.h"

#ifndef _JC_java_util_TreeMap__24Node_H_
#define _JC_java_util_TreeMap__24Node_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_TreeMap__24Node$object;

// Typedefs
typedef struct _jc_java_util_TreeMap__24Node$sub_refs	_jc_java_util_TreeMap__24Node$sub_refs;
typedef struct _jc_java_util_TreeMap__24Node$sub_nonrefs	_jc_java_util_TreeMap__24Node$sub_nonrefs;
typedef struct _jc_java_util_TreeMap__24Node$refs	_jc_java_util_TreeMap__24Node$refs;
typedef struct _jc_java_util_TreeMap__24Node$nonrefs	_jc_java_util_TreeMap__24Node$nonrefs;
typedef struct _jc_java_util_TreeMap__24Node$object	_jc_java_util_TreeMap__24Node$object;

typedef const struct _jc_java_util_TreeMap__24Node$vmethods	_jc_java_util_TreeMap__24Node$vmethods;
typedef const struct _jc_java_util_TreeMap__24Node$vtable	_jc_java_util_TreeMap__24Node$vtable;
typedef const struct _jc_java_util_TreeMap__24Node$vtype	_jc_java_util_TreeMap__24Node$vtype;

// Constructors
extern void _jc_java_util_TreeMap__24Node$method$_init$a804effe5455d5e8(_jc_env *, struct _jc_java_util_TreeMap__24Node$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_TreeMap__24Node$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_TreeMap__24Node$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_TreeMap__24Node$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_TreeMap__24Node$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_TreeMap__24Node$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_TreeMap__24Node$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_TreeMap__24Node$vmethods	java_util_TreeMap__24Node;
};

// Vtype
struct _jc_java_util_TreeMap__24Node$vtype {
	_jc_type			type;
	_jc_java_util_TreeMap__24Node$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_TreeMap__24Node$sub_refs {
	struct _jc_java_util_TreeMap__24Node$object	*left;
	struct _jc_java_util_TreeMap__24Node$object	*right;
	struct _jc_java_util_TreeMap__24Node$object	*parent;
};

// Reference instance fields (object)
struct _jc_java_util_TreeMap__24Node$refs {
    _jc_java_util_TreeMap__24Node$sub_refs	java_util_TreeMap__24Node;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_TreeMap__24Node$sub_nonrefs {
	jint	color;
};

// Non-reference instance fields (object)
struct _jc_java_util_TreeMap__24Node$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_TreeMap__24Node$sub_nonrefs	java_util_TreeMap__24Node;
};

// Object instance structure
struct _jc_java_util_TreeMap__24Node$object {
	_jc_java_util_TreeMap__24Node$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_TreeMap__24Node$vtype	*vtype;
	_jc_java_util_TreeMap__24Node$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_TreeMap__24Node$vtype _jc_java_util_TreeMap__24Node$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_TreeMap__24Node, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_TreeMap__24Node$class_object;

#endif	/* _JC_java_util_TreeMap__24Node_H_ */
